<?php

    /**
     * Created by IntelliJ IDEA.
     * User: Gavriil
     * Date: 28/3/2017
     * Time: 9:00 μμ
     */
    class Ioweb_Base_Helper_Data extends Mage_Core_Helper_Abstract
    {

        CONST ATTRIBUTE_IS_GLOBAL_VALUE_GLOBAL = 1;
        CONST ATTRIBUTE_IS_GLOBAL_VALUE_WEBSITE = 2;
        CONST ATTRIBUTE_IS_GLOBAL_VALUE_STORE_VIEW = 0;
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_TEXT = 'text';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_TEXTAREA = 'textarea';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_DATE = 'date';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_BOOLEAN = 'boolean';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_MULTISELECT = 'multiselect';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_SELECT = 'select';
        CONST ATTRIBUTE_FRONTEND_TYPE_VALUE_SELECT = 'select';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_PRICE = 'price';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_MEDIA_IMAGE = 'media_image';
        CONST ATTRIBUTE_FRONTEND_INPUT_VALUE_WEEE = 'wee';


        /**
         * @return array
         */
        public function getConfig()
        {
            $config = Mage::getStoreConfig('iowebbaseconfig_options', Mage::app()
                ->getStore());
            return $config;
        }

        /**
         * @param string $id
         */
        public function setInstallationId($id)
        {
            $this->saveConfig('iowebbaseconfig_options/information/installation_id', $id);
        }

        /**
         * @param string $path
         * @param string $value
         * @param string $scope
         * @param int $scopeId
         * @return $this
         */
        public function saveConfig($path, $value, $scope = 'default', $scopeId = 0)
        {
            $config = Mage::getConfig();
            $config->saveConfig(rtrim($path, '/'), $value, $scope, $scopeId);

            return $this;
        }

        /**
         * @param $codes
         */
        public function removeAttribute($entityType = 'catalog_product', $attributeCode)
        {
            $attributeModel = Mage::getModel('eav/entity_attribute')
                ->loadByCode($entityType, $attributeCode)
            ;
            $attributeModel->delete();
        }


        /**
         * @param string $entityType
         * @param $attributeCode
         * @param $label
         * @param string $group
         * @param $input
         * @param $values
         * @param $properties
         * possible properties:
         * apply_to => 'simple,grouped,configurable,virtual,bundle,downloadable'
         * default
         * frontend_class
         * global
         * required
         * unique
         * user_defined
         * is_comparable
         * is_filterable
         * is_filterable_in_search
         * is_html_allowed_on_front
         * is_searchable
         * is_used_for_promo_rules
         * is_visible_in_advanced_search
         * is_visible_on_front
         * position
         * used_for_sort_by
         * used_in_product_listing
         *
         */
        public function createCatalogAttribute(
            $attributeCode,
            $label,
            $group = 'IOWEB',
            $input,
            $values = null,
            $properties = array(
                'backend' => '',
                'apply_to' => 'simple,grouped,configurable,virtual,bundle,downloadable',
                'default' => null,
                'frontend' => '',
                'frontend_class' => '',
                'global' => Mage_Catalog_Model_Resource_Eav_Attribute::SCOPE_GLOBAL,
                'comparable' => false,
                'filterable' => false,
                'filterable_in_search' => false,
                'is_html_allowed_on_front' => false,
                'searchable' => true,
                'used_for_promo_rules' => true,
                'visible_in_advanced_search' => true,
                'visible_on_front' => true,
                'position' => 1,
                'required' => false,
                'source' => '',
                'unique' => true,
                'used_for_sort_by' => false,
                'used_in_product_listing' => false,
                'user_defined' => false,
                'is_configurable' => false,
            )
        )
        {
            $entityType = Mage_Catalog_Model_Product::ENTITY;

            /**
             * @var $installer Mage_Catalog_Model_Resource_Setup
             */
            $installer = Mage::getResourceModel('catalog/setup', $entityType);
            $installer->startSetup();

            if (!empty($properties['type'])) {
                $type = $properties['type'];
            } else {
                $type = $input;
            }

            $attrOptions = array(
                'type' => $type,
                'group' => $group,
                'input' => $input,
                'label' => $label,
            );

            $attrOptions = array_merge($attrOptions, $properties);

            if (!empty($values)) {
                $attrOptions['option'] = array(
                    'values' => $values,
                );
            }
            $installer->addAttribute($entityType, $attributeCode, $attrOptions);
            $installer->endSetup();

        }


        /**
         * @param $entityType string
         * @param $attributeCode string
         * @param $properties array
         * possible properties
         * is_searchable
         * is_visible_in_advanced_search
         * is_comparable
         * is_filterable
         * is_filterable_in_search
         * is_used_for_promo_rules
         * position
         * is_html_allowed_on_front
         * is_visible_on_front
         * used_in_product_listing
         * used_for_sort_by
         *
         */
        public function setAttributeFrontendProperties($entityType, $attributeCode, $properties)
        {
            $attributeModel = Mage::getModel('eav/entity_attribute')
                ->loadByCode($entityType, $attributeCode)
            ;
            foreach ($properties as $property => $value) {
                $attributeModel->setData($property, $value);
            }
            $attributeModel->save();
        }

        /**
         * @param $sku string
         * @return string
         */
        public function getProductIdBySku($sku)
        {
            $id = null;
            $model = Mage::getModel('catalog/product');
            $product = $model->loadByAttribute('sku', $sku);
            if (isset($product) && ($product != false))
                return $product->getId();
            return $id;
        }



        /**
         * @param $sku string
         * @return \Mage_Catalog_Model_Product
         */
        public function getProductBySku($sku)
        {
            $model = Mage::getModel('catalog/product');
            $product = $model->loadByAttribute('sku', $sku);
            if (isset($product) && ($product != false))
                return $product;
            return null;
        }

        /**
         * @param $attr_code string : Το όνομα του attribute που θα αλλάξει
         * @param $attr_value string : Η τιμή που θέλουμε να θέσουμε
         * @return int ? bool : Επιστρέφει το id του option με την τιμή που θέλουμε ή false
         */
        function getAttributeValue($attr_code, $attr_value)
        {
            $attribute_model = Mage::getModel('eav/entity_attribute');
            $attribute_options_model = Mage::getModel('eav/entity_attribute_source_table');
            $attribute_id = $attribute_model->getIdByCode('catalog_product', $attr_code);
            $attribute = $attribute_model->load($attribute_id);

            $attribute_table = $attribute_options_model->setAttribute($attribute);
            $options = $attribute_options_model->getAllOptions(false);

            foreach ($options as $option) {
                if ($option['label'] == $attr_value) {
                    return $option['value'];
                }
            }
            return false;
        }


        function addAndGetOptionToAttribute($attributeCode, $attributeValue){
            $attribute_model = Mage::getModel('eav/entity_attribute');
            $attribute_options_model = Mage::getModel('eav/entity_attribute_source_table');
            $attribute_id = $attribute_model->getIdByCode('catalog_product', $attributeCode);
            $attribute = $attribute_model->load($attribute_id);

            $attribute_table = $attribute_options_model->setAttribute($attribute);
            $options = $attribute_options_model->getAllOptions(false);

            foreach ($options as $option) {
                if ($option['label'] == $attributeValue) {
                    return $option['value'];
                }
            }

            //add the option and return it
            $optionId = $this->addAttributeOptions($attributeCode, $attributeValue);
            if(!empty($optionId))
                return $optionId;

            return false;

        }


        public function addAttributeOptions($attributeCode, $argValue)
        {
            $attribute = Mage::getModel('eav/config')
                ->getAttribute(Mage_Catalog_Model_Product::ENTITY, $attributeCode);


            if ($attribute->usesSource()) {

                $id = $attribute->getSource()->getOptionId($argValue);
                if ($id)
                    return $id;
            }

            $value = array('value' => array(
                'option' => array(
                    ucfirst($argValue),
                    ucfirst($argValue)
                )
            )
            );

            $attribute->setData('option', $value);
            $attribute->save();

            //return newly created option id
            $attribute = Mage::getModel('eav/config')
                ->getAttribute(Mage_Catalog_Model_Product::ENTITY, $attributeCode);
            if ($attribute->usesSource()) {
                return $attribute->getSource()->getOptionId($argValue);
            }
        }

        public function reindexEverything(){
            $indexCollection = Mage::getModel('index/process')
                ->getCollection()
            ;
            foreach ($indexCollection as $index) {
                $index->reindexAll();
            }
        }

        public function cleanCaches(){
            Mage::app()->cleanCache();
            Mage::app()->getCacheInstance()->flush();
            Mage::getSingleton('amfpc/fpc')->flush();
        }
    }